This is the documentation of **mightypy**.

Description
===========

This package initially started with the idea of expanding mightiness of python with expermenting on data structures 
and machine learning algorithms. 

visit https://mightypy.readthedocs.io/ for detailed documentation

Install from pypi:

.. code-block::

    $ pip install -U mightypy

Or, from github:

.. code-block::

    $ pip install git+https://github.com/nishantbaheti/mightypy
